aboutsummaryrefslogtreecommitdiffstats
path: root/plumbing/format/packfile/packfile.go
diff options
context:
space:
mode:
authorMiguel Molina <miguel@erizocosmi.co>2018-08-09 12:18:49 +0200
committerMiguel Molina <miguel@erizocosmi.co>2018-08-09 12:19:16 +0200
commit65dc4f9f192cc013e4765fb1162ce6ebda16573d (patch)
tree97119ae394838497b9cbb4bd0f583f6f55255e00 /plumbing/format/packfile/packfile.go
parent34cc506735ee0cd29362da51592b49a217df8159 (diff)
downloadgo-git-65dc4f9f192cc013e4765fb1162ce6ebda16573d.tar.gz
plumbing: packfile, rename DiskObject to FSObject
Signed-off-by: Miguel Molina <miguel@erizocosmi.co>
Diffstat (limited to 'plumbing/format/packfile/packfile.go')
-rw-r--r--plumbing/format/packfile/packfile.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/plumbing/format/packfile/packfile.go b/plumbing/format/packfile/packfile.go
index 37743ba..df8a3d4 100644
--- a/plumbing/format/packfile/packfile.go
+++ b/plumbing/format/packfile/packfile.go
@@ -232,7 +232,7 @@ func (p *Packfile) nextObject() (plumbing.EncodedObject, error) {
p.offsetToType[h.Offset] = typ
- return NewDiskObject(hash, typ, h.Offset, size, p), nil
+ return NewFSObject(hash, typ, h.Offset, size, p), nil
}
func (p *Packfile) getObjectContent(offset int64) (io.ReadCloser, error) {
@@ -410,7 +410,7 @@ func (p *Packfile) Close() error {
return closer.Close()
}
// MemoryObjectFromDisk converts a DiskObject to a MemoryObject.
func MemoryObjectFromDisk(obj plumbing.EncodedObject) (plumbing.EncodedObject, error) {
o2 := new(plumbing.MemoryObject)
o2.SetType(obj.Type())
@@ -410,7 +410,7 @@ func (p *Packfile) Close() error {
return closer.Close()
}
-// MemoryObjectFromDisk converts a DiskObject to a MemoryObject.
+// MemoryObjectFromDisk converts a FSObject to a MemoryObject.
func MemoryObjectFromDisk(obj plumbing.EncodedObject) (plumbing.EncodedObject, error) {
o2 := new(plumbing.MemoryObject)